@@ -1,4 +1,4 @@
-startSS <- function(gam1, gam2, formula.eq2, data, gamma, p.weights, inde, l.sp1, l.sp2, fp){
+startSS <- function(gam1, gam2, formula.eq2, data, gamma, p.weights, inde, l.sp1, l.sp2){
 
                                p.g1 <- predict(gam1)
   	 		       imr <- dnorm(p.g1)/pnorm(p.g1)
@@ -17,9 +17,9 @@ startSS <- function(gam1, gam2, formula.eq2, data, gamma, p.weights, inde, l.sp1
                                data.r <- MM/sqrt( pmax(10000*.Machine$double.eps, ta2) ) 
                                data.r <- as.data.frame(cbind(ols$model[,1],data.r)); names(data.r)[1] <- names(M)[1]
                         
-                               if(l.sp1!=0 && l.sp2!=0 && fp==FALSE) l <- as.matrix(data.r[,2:(ols$smooth[[1]]$first.para-1)]) else l <- as.matrix(data.r[,-1])
+                               if(l.sp1!=0 && l.sp2!=0) l <- as.matrix(data.r[,2:(ols$smooth[[1]]$first.para-1)]) else l <- as.matrix(data.r[,-1])
                                fw <-  paste(names(data.r)[1],"~ l",sep="")
-                               if(l.sp1!=0 && l.sp2!=0 && fp==FALSE) for(i in 1:length(ols$smooth)) fw <- paste(fw,"+",ols$smooth[[i]]$label,sep="")
+                               if(l.sp1!=0 && l.sp2!=0) for(i in 1:length(ols$smooth)) fw <- paste(fw,"+",ols$smooth[[i]]$label,sep="")
                                fw <- as.formula(fw)
 	                       gam2.1 <- suppressWarnings(try(gam(fw, binomial(link="probit"), gamma=gamma, weights=p.weights[inde], data=data.r),silent=TRUE))
 
@@ -30,7 +30,7 @@ startSS <- function(gam1, gam2, formula.eq2, data, gamma, p.weights, inde, l.sp1
                                                                 } else {
 
                                environment(gam2.1$formula) <- environment(gam1$formula)
-                               if(l.sp1!=0 && l.sp2!=0 && fp==FALSE) names(gam2.1$coefficients)[1:(ols$smooth[[1]]$first.para-1)] <- names(ols$coefficients)[1:(ols$smooth[[1]]$first.para-1)] else names(gam2.1$coefficients) <- names(ols$coefficients) 
+                               if(l.sp1!=0 && l.sp2!=0) names(gam2.1$coefficients)[1:(ols$smooth[[1]]$first.para-1)] <- names(ols$coefficients)[1:(ols$smooth[[1]]$first.para-1)] else names(gam2.1$coefficients) <- names(ols$coefficients) 
                                rho.c <- coef(gam2.1)["imr"]  
                                rho <- ifelse( abs(rho.c) > 0.99, sign(rho.c)*0.95, rho.c ); names(rho) <- "rho"
   			       start.v <- c(coef(gam1),coef(gam2.1)[names(coef(gam2.1))!="imr"], atanh(rho)  )
